# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from sonarr.models.episode_title_required_type import EpisodeTitleRequiredType
from sonarr.models.file_date_type import FileDateType
from sonarr.models.proper_download_types import ProperDownloadTypes
from sonarr.models.rescan_after_refresh_type import RescanAfterRefreshType

class MediaManagementConfigResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    auto_unmonitor_previously_downloaded_episodes: Optional[bool]
    recycle_bin: Optional[str]
    recycle_bin_cleanup_days: Optional[int]
    download_propers_and_repacks: Optional[ProperDownloadTypes]
    create_empty_series_folders: Optional[bool]
    delete_empty_folders: Optional[bool]
    file_date: Optional[FileDateType]
    rescan_after_refresh: Optional[RescanAfterRefreshType]
    set_permissions_linux: Optional[bool]
    chmod_folder: Optional[str]
    chown_group: Optional[str]
    episode_title_required: Optional[EpisodeTitleRequiredType]
    skip_free_space_check_when_importing: Optional[bool]
    minimum_free_space_when_importing: Optional[int]
    copy_using_hardlinks: Optional[bool]
    import_extra_files: Optional[bool]
    extra_file_extensions: Optional[str]
    enable_media_info: Optional[bool]
    __properties = ["id", "autoUnmonitorPreviouslyDownloadedEpisodes", "recycleBin", "recycleBinCleanupDays", "downloadPropersAndRepacks", "createEmptySeriesFolders", "deleteEmptyFolders", "fileDate", "rescanAfterRefresh", "setPermissionsLinux", "chmodFolder", "chownGroup", "episodeTitleRequired", "skipFreeSpaceCheckWhenImporting", "minimumFreeSpaceWhenImporting", "copyUsingHardlinks", "importExtraFiles", "extraFileExtensions", "enableMediaInfo"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MediaManagementConfigResource:
        """Create an instance of MediaManagementConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if recycle_bin (nullable) is None
        if self.recycle_bin is None:
            _dict['recycleBin'] = None

        # set to None if chmod_folder (nullable) is None
        if self.chmod_folder is None:
            _dict['chmodFolder'] = None

        # set to None if chown_group (nullable) is None
        if self.chown_group is None:
            _dict['chownGroup'] = None

        # set to None if extra_file_extensions (nullable) is None
        if self.extra_file_extensions is None:
            _dict['extraFileExtensions'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MediaManagementConfigResource:
        """Create an instance of MediaManagementConfigResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MediaManagementConfigResource.parse_obj(obj)

        _obj = MediaManagementConfigResource.parse_obj({
            "id": obj.get("id"),
            "auto_unmonitor_previously_downloaded_episodes": obj.get("autoUnmonitorPreviouslyDownloadedEpisodes"),
            "recycle_bin": obj.get("recycleBin"),
            "recycle_bin_cleanup_days": obj.get("recycleBinCleanupDays"),
            "download_propers_and_repacks": obj.get("downloadPropersAndRepacks"),
            "create_empty_series_folders": obj.get("createEmptySeriesFolders"),
            "delete_empty_folders": obj.get("deleteEmptyFolders"),
            "file_date": obj.get("fileDate"),
            "rescan_after_refresh": obj.get("rescanAfterRefresh"),
            "set_permissions_linux": obj.get("setPermissionsLinux"),
            "chmod_folder": obj.get("chmodFolder"),
            "chown_group": obj.get("chownGroup"),
            "episode_title_required": obj.get("episodeTitleRequired"),
            "skip_free_space_check_when_importing": obj.get("skipFreeSpaceCheckWhenImporting"),
            "minimum_free_space_when_importing": obj.get("minimumFreeSpaceWhenImporting"),
            "copy_using_hardlinks": obj.get("copyUsingHardlinks"),
            "import_extra_files": obj.get("importExtraFiles"),
            "extra_file_extensions": obj.get("extraFileExtensions"),
            "enable_media_info": obj.get("enableMediaInfo")
        })
        return _obj




# coding: utf-8

# flake8: noqa

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# x-release-please-start-version
__version__ = "0.6.0"
# x-release-please-end

# import apis into sdk package
from sonarr.api.api_info_api import ApiInfoApi
from sonarr.api.authentication_api import AuthenticationApi
from sonarr.api.auto_tagging_api import AutoTaggingApi
from sonarr.api.backup_api import BackupApi
from sonarr.api.blocklist_api import BlocklistApi
from sonarr.api.calendar_api import CalendarApi
from sonarr.api.calendar_feed_api import CalendarFeedApi
from sonarr.api.command_api import CommandApi
from sonarr.api.custom_filter_api import CustomFilterApi
from sonarr.api.custom_format_api import CustomFormatApi
from sonarr.api.cutoff_api import CutoffApi
from sonarr.api.delay_profile_api import DelayProfileApi
from sonarr.api.disk_space_api import DiskSpaceApi
from sonarr.api.download_client_api import DownloadClientApi
from sonarr.api.download_client_config_api import DownloadClientConfigApi
from sonarr.api.episode_api import EpisodeApi
from sonarr.api.episode_file_api import EpisodeFileApi
from sonarr.api.file_system_api import FileSystemApi
from sonarr.api.health_api import HealthApi
from sonarr.api.history_api import HistoryApi
from sonarr.api.host_config_api import HostConfigApi
from sonarr.api.import_list_api import ImportListApi
from sonarr.api.import_list_exclusion_api import ImportListExclusionApi
from sonarr.api.indexer_api import IndexerApi
from sonarr.api.indexer_config_api import IndexerConfigApi
from sonarr.api.initialize_js_api import InitializeJsApi
from sonarr.api.language_api import LanguageApi
from sonarr.api.language_profile_api import LanguageProfileApi
from sonarr.api.language_profile_schema_api import LanguageProfileSchemaApi
from sonarr.api.localization_api import LocalizationApi
from sonarr.api.log_api import LogApi
from sonarr.api.log_file_api import LogFileApi
from sonarr.api.manual_import_api import ManualImportApi
from sonarr.api.media_cover_api import MediaCoverApi
from sonarr.api.media_management_config_api import MediaManagementConfigApi
from sonarr.api.metadata_api import MetadataApi
from sonarr.api.missing_api import MissingApi
from sonarr.api.naming_config_api import NamingConfigApi
from sonarr.api.notification_api import NotificationApi
from sonarr.api.parse_api import ParseApi
from sonarr.api.ping_api import PingApi
from sonarr.api.quality_definition_api import QualityDefinitionApi
from sonarr.api.quality_profile_api import QualityProfileApi
from sonarr.api.quality_profile_schema_api import QualityProfileSchemaApi
from sonarr.api.queue_api import QueueApi
from sonarr.api.queue_action_api import QueueActionApi
from sonarr.api.queue_details_api import QueueDetailsApi
from sonarr.api.queue_status_api import QueueStatusApi
from sonarr.api.release_api import ReleaseApi
from sonarr.api.release_profile_api import ReleaseProfileApi
from sonarr.api.release_push_api import ReleasePushApi
from sonarr.api.remote_path_mapping_api import RemotePathMappingApi
from sonarr.api.rename_episode_api import RenameEpisodeApi
from sonarr.api.root_folder_api import RootFolderApi
from sonarr.api.season_pass_api import SeasonPassApi
from sonarr.api.series_api import SeriesApi
from sonarr.api.series_editor_api import SeriesEditorApi
from sonarr.api.series_import_api import SeriesImportApi
from sonarr.api.series_lookup_api import SeriesLookupApi
from sonarr.api.static_resource_api import StaticResourceApi
from sonarr.api.system_api import SystemApi
from sonarr.api.tag_api import TagApi
from sonarr.api.tag_details_api import TagDetailsApi
from sonarr.api.task_api import TaskApi
from sonarr.api.ui_config_api import UiConfigApi
from sonarr.api.update_api import UpdateApi
from sonarr.api.update_log_file_api import UpdateLogFileApi

# import ApiClient
from sonarr.api_client import ApiClient
from sonarr.configuration import Configuration
from sonarr.exceptions import OpenApiException
from sonarr.exceptions import ApiTypeError
from sonarr.exceptions import ApiValueError
from sonarr.exceptions import ApiKeyError
from sonarr.exceptions import ApiAttributeError
from sonarr.exceptions import ApiException
# import models into sdk package
from sonarr.models.add_series_options import AddSeriesOptions
from sonarr.models.alternate_title_resource import AlternateTitleResource
from sonarr.models.apply_tags import ApplyTags
from sonarr.models.authentication_required_type import AuthenticationRequiredType
from sonarr.models.authentication_type import AuthenticationType
from sonarr.models.auto_tagging_resource import AutoTaggingResource
from sonarr.models.auto_tagging_specification_schema import AutoTaggingSpecificationSchema
from sonarr.models.backup_resource import BackupResource
from sonarr.models.backup_type import BackupType
from sonarr.models.blocklist_bulk_resource import BlocklistBulkResource
from sonarr.models.blocklist_resource import BlocklistResource
from sonarr.models.blocklist_resource_paging_resource import BlocklistResourcePagingResource
from sonarr.models.certificate_validation_type import CertificateValidationType
from sonarr.models.command import Command
from sonarr.models.command_priority import CommandPriority
from sonarr.models.command_resource import CommandResource
from sonarr.models.command_status import CommandStatus
from sonarr.models.command_trigger import CommandTrigger
from sonarr.models.custom_filter_resource import CustomFilterResource
from sonarr.models.custom_format_resource import CustomFormatResource
from sonarr.models.custom_format_specification_schema import CustomFormatSpecificationSchema
from sonarr.models.delay_profile_resource import DelayProfileResource
from sonarr.models.disk_space_resource import DiskSpaceResource
from sonarr.models.download_client_config_resource import DownloadClientConfigResource
from sonarr.models.download_client_resource import DownloadClientResource
from sonarr.models.download_protocol import DownloadProtocol
from sonarr.models.episode_file_list_resource import EpisodeFileListResource
from sonarr.models.episode_file_resource import EpisodeFileResource
from sonarr.models.episode_history_event_type import EpisodeHistoryEventType
from sonarr.models.episode_resource import EpisodeResource
from sonarr.models.episode_resource_paging_resource import EpisodeResourcePagingResource
from sonarr.models.episode_title_required_type import EpisodeTitleRequiredType
from sonarr.models.episodes_monitored_resource import EpisodesMonitoredResource
from sonarr.models.field import Field
from sonarr.models.file_date_type import FileDateType
from sonarr.models.health_check_result import HealthCheckResult
from sonarr.models.health_resource import HealthResource
from sonarr.models.history_resource import HistoryResource
from sonarr.models.history_resource_paging_resource import HistoryResourcePagingResource
from sonarr.models.host_config_resource import HostConfigResource
from sonarr.models.import_list_exclusion_resource import ImportListExclusionResource
from sonarr.models.import_list_resource import ImportListResource
from sonarr.models.import_list_type import ImportListType
from sonarr.models.indexer_config_resource import IndexerConfigResource
from sonarr.models.indexer_resource import IndexerResource
from sonarr.models.language import Language
from sonarr.models.language_profile_item_resource import LanguageProfileItemResource
from sonarr.models.language_profile_resource import LanguageProfileResource
from sonarr.models.language_resource import LanguageResource
from sonarr.models.localization_language_resource import LocalizationLanguageResource
from sonarr.models.localization_resource import LocalizationResource
from sonarr.models.log_file_resource import LogFileResource
from sonarr.models.log_resource import LogResource
from sonarr.models.log_resource_paging_resource import LogResourcePagingResource
from sonarr.models.manual_import_reprocess_resource import ManualImportReprocessResource
from sonarr.models.manual_import_resource import ManualImportResource
from sonarr.models.media_cover import MediaCover
from sonarr.models.media_cover_types import MediaCoverTypes
from sonarr.models.media_info_resource import MediaInfoResource
from sonarr.models.media_management_config_resource import MediaManagementConfigResource
from sonarr.models.metadata_resource import MetadataResource
from sonarr.models.monitor_types import MonitorTypes
from sonarr.models.monitoring_options import MonitoringOptions
from sonarr.models.naming_config_resource import NamingConfigResource
from sonarr.models.notification_resource import NotificationResource
from sonarr.models.paging_resource_filter import PagingResourceFilter
from sonarr.models.parse_resource import ParseResource
from sonarr.models.parsed_episode_info import ParsedEpisodeInfo
from sonarr.models.ping_resource import PingResource
from sonarr.models.privacy_level import PrivacyLevel
from sonarr.models.profile_format_item_resource import ProfileFormatItemResource
from sonarr.models.proper_download_types import ProperDownloadTypes
from sonarr.models.provider_message import ProviderMessage
from sonarr.models.provider_message_type import ProviderMessageType
from sonarr.models.proxy_type import ProxyType
from sonarr.models.quality import Quality
from sonarr.models.quality_definition_resource import QualityDefinitionResource
from sonarr.models.quality_model import QualityModel
from sonarr.models.quality_profile_quality_item_resource import QualityProfileQualityItemResource
from sonarr.models.quality_profile_resource import QualityProfileResource
from sonarr.models.quality_source import QualitySource
from sonarr.models.queue_bulk_resource import QueueBulkResource
from sonarr.models.queue_resource import QueueResource
from sonarr.models.queue_resource_paging_resource import QueueResourcePagingResource
from sonarr.models.queue_status_resource import QueueStatusResource
from sonarr.models.ratings import Ratings
from sonarr.models.rejection import Rejection
from sonarr.models.rejection_type import RejectionType
from sonarr.models.release_profile_resource import ReleaseProfileResource
from sonarr.models.release_resource import ReleaseResource
from sonarr.models.remote_path_mapping_resource import RemotePathMappingResource
from sonarr.models.rename_episode_resource import RenameEpisodeResource
from sonarr.models.rescan_after_refresh_type import RescanAfterRefreshType
from sonarr.models.revision import Revision
from sonarr.models.root_folder_resource import RootFolderResource
from sonarr.models.runtime_mode import RuntimeMode
from sonarr.models.season_pass_resource import SeasonPassResource
from sonarr.models.season_pass_series_resource import SeasonPassSeriesResource
from sonarr.models.season_resource import SeasonResource
from sonarr.models.season_statistics_resource import SeasonStatisticsResource
from sonarr.models.select_option import SelectOption
from sonarr.models.series_editor_resource import SeriesEditorResource
from sonarr.models.series_resource import SeriesResource
from sonarr.models.series_statistics_resource import SeriesStatisticsResource
from sonarr.models.series_status_type import SeriesStatusType
from sonarr.models.series_title_info import SeriesTitleInfo
from sonarr.models.series_types import SeriesTypes
from sonarr.models.sort_direction import SortDirection
from sonarr.models.system_resource import SystemResource
from sonarr.models.tag_details_resource import TagDetailsResource
from sonarr.models.tag_resource import TagResource
from sonarr.models.task_resource import TaskResource
from sonarr.models.tracked_download_state import TrackedDownloadState
from sonarr.models.tracked_download_status import TrackedDownloadStatus
from sonarr.models.tracked_download_status_message import TrackedDownloadStatusMessage
from sonarr.models.ui_config_resource import UiConfigResource
from sonarr.models.unmapped_folder import UnmappedFolder
from sonarr.models.update_changes import UpdateChanges
from sonarr.models.update_mechanism import UpdateMechanism
from sonarr.models.update_resource import UpdateResource



# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.episode_file_resource import EpisodeFileResource
from sonarr.models.media_cover import MediaCover
from sonarr.models.series_resource import SeriesResource

class EpisodeResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    series_id: Optional[int]
    tvdb_id: Optional[int]
    episode_file_id: Optional[int]
    season_number: Optional[int]
    episode_number: Optional[int]
    title: Optional[str]
    air_date: Optional[str]
    air_date_utc: Optional[datetime]
    overview: Optional[str]
    episode_file: Optional[EpisodeFileResource]
    has_file: Optional[bool]
    monitored: Optional[bool]
    absolute_episode_number: Optional[int]
    scene_absolute_episode_number: Optional[int]
    scene_episode_number: Optional[int]
    scene_season_number: Optional[int]
    unverified_scene_numbering: Optional[bool]
    end_time: Optional[datetime]
    grab_date: Optional[datetime]
    series_title: Optional[str]
    series: Optional[SeriesResource]
    images: Optional[List]
    grabbed: Optional[bool]
    __properties = ["id", "seriesId", "tvdbId", "episodeFileId", "seasonNumber", "episodeNumber", "title", "airDate", "airDateUtc", "overview", "episodeFile", "hasFile", "monitored", "absoluteEpisodeNumber", "sceneAbsoluteEpisodeNumber", "sceneEpisodeNumber", "sceneSeasonNumber", "unverifiedSceneNumbering", "endTime", "grabDate", "seriesTitle", "series", "images", "grabbed"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EpisodeResource:
        """Create an instance of EpisodeResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of episode_file
        if self.episode_file:
            _dict['episodeFile'] = self.episode_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of series
        if self.series:
            _dict['series'] = self.series.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if air_date (nullable) is None
        if self.air_date is None:
            _dict['airDate'] = None

        # set to None if air_date_utc (nullable) is None
        if self.air_date_utc is None:
            _dict['airDateUtc'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if absolute_episode_number (nullable) is None
        if self.absolute_episode_number is None:
            _dict['absoluteEpisodeNumber'] = None

        # set to None if scene_absolute_episode_number (nullable) is None
        if self.scene_absolute_episode_number is None:
            _dict['sceneAbsoluteEpisodeNumber'] = None

        # set to None if scene_episode_number (nullable) is None
        if self.scene_episode_number is None:
            _dict['sceneEpisodeNumber'] = None

        # set to None if scene_season_number (nullable) is None
        if self.scene_season_number is None:
            _dict['sceneSeasonNumber'] = None

        # set to None if end_time (nullable) is None
        if self.end_time is None:
            _dict['endTime'] = None

        # set to None if grab_date (nullable) is None
        if self.grab_date is None:
            _dict['grabDate'] = None

        # set to None if series_title (nullable) is None
        if self.series_title is None:
            _dict['seriesTitle'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EpisodeResource:
        """Create an instance of EpisodeResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return EpisodeResource.parse_obj(obj)

        _obj = EpisodeResource.parse_obj({
            "id": obj.get("id"),
            "series_id": obj.get("seriesId"),
            "tvdb_id": obj.get("tvdbId"),
            "episode_file_id": obj.get("episodeFileId"),
            "season_number": obj.get("seasonNumber"),
            "episode_number": obj.get("episodeNumber"),
            "title": obj.get("title"),
            "air_date": obj.get("airDate"),
            "air_date_utc": obj.get("airDateUtc"),
            "overview": obj.get("overview"),
            "episode_file": EpisodeFileResource.from_dict(obj.get("episodeFile")) if obj.get("episodeFile") is not None else None,
            "has_file": obj.get("hasFile"),
            "monitored": obj.get("monitored"),
            "absolute_episode_number": obj.get("absoluteEpisodeNumber"),
            "scene_absolute_episode_number": obj.get("sceneAbsoluteEpisodeNumber"),
            "scene_episode_number": obj.get("sceneEpisodeNumber"),
            "scene_season_number": obj.get("sceneSeasonNumber"),
            "unverified_scene_numbering": obj.get("unverifiedSceneNumbering"),
            "end_time": obj.get("endTime"),
            "grab_date": obj.get("grabDate"),
            "series_title": obj.get("seriesTitle"),
            "series": SeriesResource.from_dict(obj.get("series")) if obj.get("series") is not None else None,
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "grabbed": obj.get("grabbed")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.episode_resource import EpisodeResource
from sonarr.models.language import Language
from sonarr.models.quality_model import QualityModel
from sonarr.models.rejection import Rejection

class ManualImportReprocessResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    path: Optional[str]
    series_id: Optional[int]
    season_number: Optional[int]
    episodes: Optional[List]
    episode_ids: Optional[List]
    quality: Optional[QualityModel]
    languages: Optional[List]
    release_group: Optional[str]
    download_id: Optional[str]
    rejections: Optional[List]
    __properties = ["id", "path", "seriesId", "seasonNumber", "episodes", "episodeIds", "quality", "languages", "releaseGroup", "downloadId", "rejections"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ManualImportReprocessResource:
        """Create an instance of ManualImportReprocessResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in episodes (list)
        _items = []
        if self.episodes:
            for _item in self.episodes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['episodes'] = _items
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item in self.languages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['languages'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in rejections (list)
        _items = []
        if self.rejections:
            for _item in self.rejections:
                if _item:
                    _items.append(_item.to_dict())
            _dict['rejections'] = _items
        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        # set to None if season_number (nullable) is None
        if self.season_number is None:
            _dict['seasonNumber'] = None

        # set to None if episodes (nullable) is None
        if self.episodes is None:
            _dict['episodes'] = None

        # set to None if episode_ids (nullable) is None
        if self.episode_ids is None:
            _dict['episodeIds'] = None

        # set to None if languages (nullable) is None
        if self.languages is None:
            _dict['languages'] = None

        # set to None if release_group (nullable) is None
        if self.release_group is None:
            _dict['releaseGroup'] = None

        # set to None if download_id (nullable) is None
        if self.download_id is None:
            _dict['downloadId'] = None

        # set to None if rejections (nullable) is None
        if self.rejections is None:
            _dict['rejections'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ManualImportReprocessResource:
        """Create an instance of ManualImportReprocessResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ManualImportReprocessResource.parse_obj(obj)

        _obj = ManualImportReprocessResource.parse_obj({
            "id": obj.get("id"),
            "path": obj.get("path"),
            "series_id": obj.get("seriesId"),
            "season_number": obj.get("seasonNumber"),
            "episodes": [EpisodeResource.from_dict(_item) for _item in obj.get("episodes")] if obj.get("episodes") is not None else None,
            "episode_ids": obj.get("episodeIds"),
            "quality": QualityModel.from_dict(obj.get("quality")) if obj.get("quality") is not None else None,
            "languages": [Language.from_dict(_item) for _item in obj.get("languages")] if obj.get("languages") is not None else None,
            "release_group": obj.get("releaseGroup"),
            "download_id": obj.get("downloadId"),
            "rejections": [Rejection.from_dict(_item) for _item in obj.get("rejections")] if obj.get("rejections") is not None else None
        })
        return _obj




# coding: utf-8

# flake8: noqa

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from sonarr.models.add_series_options import AddSeriesOptions
from sonarr.models.alternate_title_resource import AlternateTitleResource
from sonarr.models.apply_tags import ApplyTags
from sonarr.models.authentication_required_type import AuthenticationRequiredType
from sonarr.models.authentication_type import AuthenticationType
from sonarr.models.auto_tagging_resource import AutoTaggingResource
from sonarr.models.auto_tagging_specification_schema import AutoTaggingSpecificationSchema
from sonarr.models.backup_resource import BackupResource
from sonarr.models.backup_type import BackupType
from sonarr.models.blocklist_bulk_resource import BlocklistBulkResource
from sonarr.models.blocklist_resource import BlocklistResource
from sonarr.models.blocklist_resource_paging_resource import BlocklistResourcePagingResource
from sonarr.models.certificate_validation_type import CertificateValidationType
from sonarr.models.command import Command
from sonarr.models.command_priority import CommandPriority
from sonarr.models.command_resource import CommandResource
from sonarr.models.command_status import CommandStatus
from sonarr.models.command_trigger import CommandTrigger
from sonarr.models.custom_filter_resource import CustomFilterResource
from sonarr.models.custom_format_resource import CustomFormatResource
from sonarr.models.custom_format_specification_schema import CustomFormatSpecificationSchema
from sonarr.models.delay_profile_resource import DelayProfileResource
from sonarr.models.disk_space_resource import DiskSpaceResource
from sonarr.models.download_client_config_resource import DownloadClientConfigResource
from sonarr.models.download_client_resource import DownloadClientResource
from sonarr.models.download_protocol import DownloadProtocol
from sonarr.models.episode_file_list_resource import EpisodeFileListResource
from sonarr.models.episode_file_resource import EpisodeFileResource
from sonarr.models.episode_history_event_type import EpisodeHistoryEventType
from sonarr.models.episode_resource import EpisodeResource
from sonarr.models.episode_resource_paging_resource import EpisodeResourcePagingResource
from sonarr.models.episode_title_required_type import EpisodeTitleRequiredType
from sonarr.models.episodes_monitored_resource import EpisodesMonitoredResource
from sonarr.models.field import Field
from sonarr.models.file_date_type import FileDateType
from sonarr.models.health_check_result import HealthCheckResult
from sonarr.models.health_resource import HealthResource
from sonarr.models.history_resource import HistoryResource
from sonarr.models.history_resource_paging_resource import HistoryResourcePagingResource
from sonarr.models.host_config_resource import HostConfigResource
from sonarr.models.import_list_exclusion_resource import ImportListExclusionResource
from sonarr.models.import_list_resource import ImportListResource
from sonarr.models.import_list_type import ImportListType
from sonarr.models.indexer_config_resource import IndexerConfigResource
from sonarr.models.indexer_resource import IndexerResource
from sonarr.models.language import Language
from sonarr.models.language_profile_item_resource import LanguageProfileItemResource
from sonarr.models.language_profile_resource import LanguageProfileResource
from sonarr.models.language_resource import LanguageResource
from sonarr.models.localization_language_resource import LocalizationLanguageResource
from sonarr.models.localization_resource import LocalizationResource
from sonarr.models.log_file_resource import LogFileResource
from sonarr.models.log_resource import LogResource
from sonarr.models.log_resource_paging_resource import LogResourcePagingResource
from sonarr.models.manual_import_reprocess_resource import ManualImportReprocessResource
from sonarr.models.manual_import_resource import ManualImportResource
from sonarr.models.media_cover import MediaCover
from sonarr.models.media_cover_types import MediaCoverTypes
from sonarr.models.media_info_resource import MediaInfoResource
from sonarr.models.media_management_config_resource import MediaManagementConfigResource
from sonarr.models.metadata_resource import MetadataResource
from sonarr.models.monitor_types import MonitorTypes
from sonarr.models.monitoring_options import MonitoringOptions
from sonarr.models.naming_config_resource import NamingConfigResource
from sonarr.models.notification_resource import NotificationResource
from sonarr.models.paging_resource_filter import PagingResourceFilter
from sonarr.models.parse_resource import ParseResource
from sonarr.models.parsed_episode_info import ParsedEpisodeInfo
from sonarr.models.ping_resource import PingResource
from sonarr.models.privacy_level import PrivacyLevel
from sonarr.models.profile_format_item_resource import ProfileFormatItemResource
from sonarr.models.proper_download_types import ProperDownloadTypes
from sonarr.models.provider_message import ProviderMessage
from sonarr.models.provider_message_type import ProviderMessageType
from sonarr.models.proxy_type import ProxyType
from sonarr.models.quality import Quality
from sonarr.models.quality_definition_resource import QualityDefinitionResource
from sonarr.models.quality_model import QualityModel
from sonarr.models.quality_profile_quality_item_resource import QualityProfileQualityItemResource
from sonarr.models.quality_profile_resource import QualityProfileResource
from sonarr.models.quality_source import QualitySource
from sonarr.models.queue_bulk_resource import QueueBulkResource
from sonarr.models.queue_resource import QueueResource
from sonarr.models.queue_resource_paging_resource import QueueResourcePagingResource
from sonarr.models.queue_status_resource import QueueStatusResource
from sonarr.models.ratings import Ratings
from sonarr.models.rejection import Rejection
from sonarr.models.rejection_type import RejectionType
from sonarr.models.release_profile_resource import ReleaseProfileResource
from sonarr.models.release_resource import ReleaseResource
from sonarr.models.remote_path_mapping_resource import RemotePathMappingResource
from sonarr.models.rename_episode_resource import RenameEpisodeResource
from sonarr.models.rescan_after_refresh_type import RescanAfterRefreshType
from sonarr.models.revision import Revision
from sonarr.models.root_folder_resource import RootFolderResource
from sonarr.models.runtime_mode import RuntimeMode
from sonarr.models.season_pass_resource import SeasonPassResource
from sonarr.models.season_pass_series_resource import SeasonPassSeriesResource
from sonarr.models.season_resource import SeasonResource
from sonarr.models.season_statistics_resource import SeasonStatisticsResource
from sonarr.models.select_option import SelectOption
from sonarr.models.series_editor_resource import SeriesEditorResource
from sonarr.models.series_resource import SeriesResource
from sonarr.models.series_statistics_resource import SeriesStatisticsResource
from sonarr.models.series_status_type import SeriesStatusType
from sonarr.models.series_title_info import SeriesTitleInfo
from sonarr.models.series_types import SeriesTypes
from sonarr.models.sort_direction import SortDirection
from sonarr.models.system_resource import SystemResource
from sonarr.models.tag_details_resource import TagDetailsResource
from sonarr.models.tag_resource import TagResource
from sonarr.models.task_resource import TaskResource
from sonarr.models.tracked_download_state import TrackedDownloadState
from sonarr.models.tracked_download_status import TrackedDownloadStatus
from sonarr.models.tracked_download_status_message import TrackedDownloadStatusMessage
from sonarr.models.ui_config_resource import UiConfigResource
from sonarr.models.unmapped_folder import UnmappedFolder
from sonarr.models.update_changes import UpdateChanges
from sonarr.models.update_mechanism import UpdateMechanism
from sonarr.models.update_resource import UpdateResource



# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class RescanAfterRefreshType(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    ALWAYS = 'always'
    AFTERMANUAL = 'afterManual'
    NEVER = 'never'




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.apply_tags import ApplyTags
from sonarr.models.series_types import SeriesTypes

class SeriesEditorResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    series_ids: Optional[List]
    monitored: Optional[bool]
    quality_profile_id: Optional[int]
    series_type: Optional[SeriesTypes]
    season_folder: Optional[bool]
    root_folder_path: Optional[str]
    tags: Optional[List]
    apply_tags: Optional[ApplyTags]
    move_files: Optional[bool]
    delete_files: Optional[bool]
    add_import_list_exclusion: Optional[bool]
    __properties = ["seriesIds", "monitored", "qualityProfileId", "seriesType", "seasonFolder", "rootFolderPath", "tags", "applyTags", "moveFiles", "deleteFiles", "addImportListExclusion"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SeriesEditorResource:
        """Create an instance of SeriesEditorResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if series_ids (nullable) is None
        if self.series_ids is None:
            _dict['seriesIds'] = None

        # set to None if monitored (nullable) is None
        if self.monitored is None:
            _dict['monitored'] = None

        # set to None if quality_profile_id (nullable) is None
        if self.quality_profile_id is None:
            _dict['qualityProfileId'] = None

        # set to None if season_folder (nullable) is None
        if self.season_folder is None:
            _dict['seasonFolder'] = None

        # set to None if root_folder_path (nullable) is None
        if self.root_folder_path is None:
            _dict['rootFolderPath'] = None

        # set to None if tags (nullable) is None
        if self.tags is None:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SeriesEditorResource:
        """Create an instance of SeriesEditorResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return SeriesEditorResource.parse_obj(obj)

        _obj = SeriesEditorResource.parse_obj({
            "series_ids": obj.get("seriesIds"),
            "monitored": obj.get("monitored"),
            "quality_profile_id": obj.get("qualityProfileId"),
            "series_type": obj.get("seriesType"),
            "season_folder": obj.get("seasonFolder"),
            "root_folder_path": obj.get("rootFolderPath"),
            "tags": obj.get("tags"),
            "apply_tags": obj.get("applyTags"),
            "move_files": obj.get("moveFiles"),
            "delete_files": obj.get("deleteFiles"),
            "add_import_list_exclusion": obj.get("addImportListExclusion")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, validator
from sonarr.models.field import Field
from sonarr.models.import_list_type import ImportListType
from sonarr.models.monitor_types import MonitorTypes
from sonarr.models.provider_message import ProviderMessage
from sonarr.models.series_types import SeriesTypes

class ImportListResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    name: Optional[str]
    fields: Optional[List]
    implementation_name: Optional[str]
    implementation: Optional[str]
    config_contract: Optional[str]
    info_link: Optional[str]
    message: Optional[ProviderMessage]
    tags: Optional[List]
    presets: Optional[List]
    enable_automatic_add: Optional[bool]
    should_monitor: Optional[MonitorTypes]
    root_folder_path: Optional[str]
    quality_profile_id: Optional[int]
    series_type: Optional[SeriesTypes]
    season_folder: Optional[bool]
    list_type: Optional[ImportListType]
    list_order: Optional[int]
    min_refresh_interval: Optional[str]
    __properties = ["id", "name", "fields", "implementationName", "implementation", "configContract", "infoLink", "message", "tags", "presets", "enableAutomaticAdd", "shouldMonitor", "rootFolderPath", "qualityProfileId", "seriesType", "seasonFolder", "listType", "listOrder", "minRefreshInterval"]

    @validator('min_refresh_interval')
    def min_refresh_interval_validate_regular_expression(cls, v):
        if not re.match(r"\d{2}:\d{2}:\d{2}", v):
            raise ValueError(r"must validate the regular expression /\d{2}:\d{2}:\d{2}/")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ImportListResource:
        """Create an instance of ImportListResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in fields (list)
        _items = []
        if self.fields:
            for _item in self.fields:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fields'] = _items
        # override the default output from pydantic by calling `to_dict()` of message
        if self.message:
            _dict['message'] = self.message.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in presets (list)
        _items = []
        if self.presets:
            for _item in self.presets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['presets'] = _items
        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if fields (nullable) is None
        if self.fields is None:
            _dict['fields'] = None

        # set to None if implementation_name (nullable) is None
        if self.implementation_name is None:
            _dict['implementationName'] = None

        # set to None if implementation (nullable) is None
        if self.implementation is None:
            _dict['implementation'] = None

        # set to None if config_contract (nullable) is None
        if self.config_contract is None:
            _dict['configContract'] = None

        # set to None if info_link (nullable) is None
        if self.info_link is None:
            _dict['infoLink'] = None

        # set to None if tags (nullable) is None
        if self.tags is None:
            _dict['tags'] = None

        # set to None if presets (nullable) is None
        if self.presets is None:
            _dict['presets'] = None

        # set to None if root_folder_path (nullable) is None
        if self.root_folder_path is None:
            _dict['rootFolderPath'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ImportListResource:
        """Create an instance of ImportListResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ImportListResource.parse_obj(obj)

        _obj = ImportListResource.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "fields": [Field.from_dict(_item) for _item in obj.get("fields")] if obj.get("fields") is not None else None,
            "implementation_name": obj.get("implementationName"),
            "implementation": obj.get("implementation"),
            "config_contract": obj.get("configContract"),
            "info_link": obj.get("infoLink"),
            "message": ProviderMessage.from_dict(obj.get("message")) if obj.get("message") is not None else None,
            "tags": obj.get("tags"),
            "presets": [ImportListResource.from_dict(_item) for _item in obj.get("presets")] if obj.get("presets") is not None else None,
            "enable_automatic_add": obj.get("enableAutomaticAdd"),
            "should_monitor": obj.get("shouldMonitor"),
            "root_folder_path": obj.get("rootFolderPath"),
            "quality_profile_id": obj.get("qualityProfileId"),
            "series_type": obj.get("seriesType"),
            "season_folder": obj.get("seasonFolder"),
            "list_type": obj.get("listType"),
            "list_order": obj.get("listOrder"),
            "min_refresh_interval": obj.get("minRefreshInterval")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, List, Optional
from pydantic import BaseModel
from sonarr.models.custom_format_resource import CustomFormatResource
from sonarr.models.episode_history_event_type import EpisodeHistoryEventType
from sonarr.models.episode_resource import EpisodeResource
from sonarr.models.language import Language
from sonarr.models.quality_model import QualityModel
from sonarr.models.series_resource import SeriesResource

class HistoryResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    episode_id: Optional[int]
    series_id: Optional[int]
    source_title: Optional[str]
    languages: Optional[List]
    quality: Optional[QualityModel]
    custom_formats: Optional[List]
    custom_format_score: Optional[int]
    quality_cutoff_not_met: Optional[bool]
    var_date: Optional[datetime]
    download_id: Optional[str]
    event_type: Optional[EpisodeHistoryEventType]
    data: Optional[Dict]
    episode: Optional[EpisodeResource]
    series: Optional[SeriesResource]
    __properties = ["id", "episodeId", "seriesId", "sourceTitle", "languages", "quality", "customFormats", "customFormatScore", "qualityCutoffNotMet", "date", "downloadId", "eventType", "data", "episode", "series"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> HistoryResource:
        """Create an instance of HistoryResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item in self.languages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['languages'] = _items
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in custom_formats (list)
        _items = []
        if self.custom_formats:
            for _item in self.custom_formats:
                if _item:
                    _items.append(_item.to_dict())
            _dict['customFormats'] = _items
        # override the default output from pydantic by calling `to_dict()` of episode
        if self.episode:
            _dict['episode'] = self.episode.to_dict()
        # override the default output from pydantic by calling `to_dict()` of series
        if self.series:
            _dict['series'] = self.series.to_dict()
        # set to None if source_title (nullable) is None
        if self.source_title is None:
            _dict['sourceTitle'] = None

        # set to None if languages (nullable) is None
        if self.languages is None:
            _dict['languages'] = None

        # set to None if custom_formats (nullable) is None
        if self.custom_formats is None:
            _dict['customFormats'] = None

        # set to None if download_id (nullable) is None
        if self.download_id is None:
            _dict['downloadId'] = None

        # set to None if data (nullable) is None
        if self.data is None:
            _dict['data'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> HistoryResource:
        """Create an instance of HistoryResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return HistoryResource.parse_obj(obj)

        _obj = HistoryResource.parse_obj({
            "id": obj.get("id"),
            "episode_id": obj.get("episodeId"),
            "series_id": obj.get("seriesId"),
            "source_title": obj.get("sourceTitle"),
            "languages": [Language.from_dict(_item) for _item in obj.get("languages")] if obj.get("languages") is not None else None,
            "quality": QualityModel.from_dict(obj.get("quality")) if obj.get("quality") is not None else None,
            "custom_formats": [CustomFormatResource.from_dict(_item) for _item in obj.get("customFormats")] if obj.get("customFormats") is not None else None,
            "custom_format_score": obj.get("customFormatScore"),
            "quality_cutoff_not_met": obj.get("qualityCutoffNotMet"),
            "var_date": obj.get("date"),
            "download_id": obj.get("downloadId"),
            "event_type": obj.get("eventType"),
            "data": obj.get("data"),
            "episode": EpisodeResource.from_dict(obj.get("episode")) if obj.get("episode") is not None else None,
            "series": SeriesResource.from_dict(obj.get("series")) if obj.get("series") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, List, Optional
from pydantic import BaseModel
from sonarr.models.privacy_level import PrivacyLevel
from sonarr.models.select_option import SelectOption

class Field(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    order: Optional[int]
    name: Optional[str]
    label: Optional[str]
    unit: Optional[str]
    help_text: Optional[str]
    help_link: Optional[str]
    value: Optional[object]
    type: Optional[str]
    advanced: Optional[bool]
    select_options: Optional[List]
    select_options_provider_action: Optional[str]
    section: Optional[str]
    hidden: Optional[str]
    privacy: Optional[PrivacyLevel]
    __properties = ["order", "name", "label", "unit", "helpText", "helpLink", "value", "type", "advanced", "selectOptions", "selectOptionsProviderAction", "section", "hidden", "privacy"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Field:
        """Create an instance of Field from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in select_options (list)
        _items = []
        if self.select_options:
            for _item in self.select_options:
                if _item:
                    _items.append(_item.to_dict())
            _dict['selectOptions'] = _items
        # set to None if name (nullable) is None
        if self.name is None:
            _dict['name'] = None

        # set to None if label (nullable) is None
        if self.label is None:
            _dict['label'] = None

        # set to None if unit (nullable) is None
        if self.unit is None:
            _dict['unit'] = None

        # set to None if help_text (nullable) is None
        if self.help_text is None:
            _dict['helpText'] = None

        # set to None if help_link (nullable) is None
        if self.help_link is None:
            _dict['helpLink'] = None

        # set to None if value (nullable) is None
        if self.value is None:
            _dict['value'] = None

        # set to None if type (nullable) is None
        if self.type is None:
            _dict['type'] = None

        # set to None if select_options (nullable) is None
        if self.select_options is None:
            _dict['selectOptions'] = None

        # set to None if select_options_provider_action (nullable) is None
        if self.select_options_provider_action is None:
            _dict['selectOptionsProviderAction'] = None

        # set to None if section (nullable) is None
        if self.section is None:
            _dict['section'] = None

        # set to None if hidden (nullable) is None
        if self.hidden is None:
            _dict['hidden'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Field:
        """Create an instance of Field from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Field.parse_obj(obj)

        _obj = Field.parse_obj({
            "order": obj.get("order"),
            "name": obj.get("name"),
            "label": obj.get("label"),
            "unit": obj.get("unit"),
            "help_text": obj.get("helpText"),
            "help_link": obj.get("helpLink"),
            "value": obj.get("value"),
            "type": obj.get("type"),
            "advanced": obj.get("advanced"),
            "select_options": [SelectOption.from_dict(_item) for _item in obj.get("selectOptions")] if obj.get("selectOptions") is not None else None,
            "select_options_provider_action": obj.get("selectOptionsProviderAction"),
            "section": obj.get("section"),
            "hidden": obj.get("hidden"),
            "privacy": obj.get("privacy")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.add_series_options import AddSeriesOptions
from sonarr.models.alternate_title_resource import AlternateTitleResource
from sonarr.models.language import Language
from sonarr.models.media_cover import MediaCover
from sonarr.models.ratings import Ratings
from sonarr.models.season_resource import SeasonResource
from sonarr.models.series_statistics_resource import SeriesStatisticsResource
from sonarr.models.series_status_type import SeriesStatusType
from sonarr.models.series_types import SeriesTypes

class SeriesResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    title: Optional[str]
    alternate_titles: Optional[List]
    sort_title: Optional[str]
    status: Optional[SeriesStatusType]
    ended: Optional[bool]
    profile_name: Optional[str]
    overview: Optional[str]
    next_airing: Optional[datetime]
    previous_airing: Optional[datetime]
    network: Optional[str]
    air_time: Optional[str]
    images: Optional[List]
    original_language: Optional[Language]
    remote_poster: Optional[str]
    seasons: Optional[List]
    year: Optional[int]
    path: Optional[str]
    quality_profile_id: Optional[int]
    season_folder: Optional[bool]
    monitored: Optional[bool]
    use_scene_numbering: Optional[bool]
    runtime: Optional[int]
    tvdb_id: Optional[int]
    tv_rage_id: Optional[int]
    tv_maze_id: Optional[int]
    first_aired: Optional[datetime]
    series_type: Optional[SeriesTypes]
    clean_title: Optional[str]
    imdb_id: Optional[str]
    title_slug: Optional[str]
    root_folder_path: Optional[str]
    folder: Optional[str]
    certification: Optional[str]
    genres: Optional[List]
    tags: Optional[List]
    added: Optional[datetime]
    add_options: Optional[AddSeriesOptions]
    ratings: Optional[Ratings]
    statistics: Optional[SeriesStatisticsResource]
    episodes_changed: Optional[bool]
    language_profile_id: Optional[int]
    __properties = ["id", "title", "alternateTitles", "sortTitle", "status", "ended", "profileName", "overview", "nextAiring", "previousAiring", "network", "airTime", "images", "originalLanguage", "remotePoster", "seasons", "year", "path", "qualityProfileId", "seasonFolder", "monitored", "useSceneNumbering", "runtime", "tvdbId", "tvRageId", "tvMazeId", "firstAired", "seriesType", "cleanTitle", "imdbId", "titleSlug", "rootFolderPath", "folder", "certification", "genres", "tags", "added", "addOptions", "ratings", "statistics", "episodesChanged", "languageProfileId"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SeriesResource:
        """Create an instance of SeriesResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "ended",
                            "language_profile_id",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in alternate_titles (list)
        _items = []
        if self.alternate_titles:
            for _item in self.alternate_titles:
                if _item:
                    _items.append(_item.to_dict())
            _dict['alternateTitles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of original_language
        if self.original_language:
            _dict['originalLanguage'] = self.original_language.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in seasons (list)
        _items = []
        if self.seasons:
            for _item in self.seasons:
                if _item:
                    _items.append(_item.to_dict())
            _dict['seasons'] = _items
        # override the default output from pydantic by calling `to_dict()` of add_options
        if self.add_options:
            _dict['addOptions'] = self.add_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of statistics
        if self.statistics:
            _dict['statistics'] = self.statistics.to_dict()
        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if alternate_titles (nullable) is None
        if self.alternate_titles is None:
            _dict['alternateTitles'] = None

        # set to None if sort_title (nullable) is None
        if self.sort_title is None:
            _dict['sortTitle'] = None

        # set to None if profile_name (nullable) is None
        if self.profile_name is None:
            _dict['profileName'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if next_airing (nullable) is None
        if self.next_airing is None:
            _dict['nextAiring'] = None

        # set to None if previous_airing (nullable) is None
        if self.previous_airing is None:
            _dict['previousAiring'] = None

        # set to None if network (nullable) is None
        if self.network is None:
            _dict['network'] = None

        # set to None if air_time (nullable) is None
        if self.air_time is None:
            _dict['airTime'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if remote_poster (nullable) is None
        if self.remote_poster is None:
            _dict['remotePoster'] = None

        # set to None if seasons (nullable) is None
        if self.seasons is None:
            _dict['seasons'] = None

        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        # set to None if first_aired (nullable) is None
        if self.first_aired is None:
            _dict['firstAired'] = None

        # set to None if clean_title (nullable) is None
        if self.clean_title is None:
            _dict['cleanTitle'] = None

        # set to None if imdb_id (nullable) is None
        if self.imdb_id is None:
            _dict['imdbId'] = None

        # set to None if title_slug (nullable) is None
        if self.title_slug is None:
            _dict['titleSlug'] = None

        # set to None if root_folder_path (nullable) is None
        if self.root_folder_path is None:
            _dict['rootFolderPath'] = None

        # set to None if folder (nullable) is None
        if self.folder is None:
            _dict['folder'] = None

        # set to None if certification (nullable) is None
        if self.certification is None:
            _dict['certification'] = None

        # set to None if genres (nullable) is None
        if self.genres is None:
            _dict['genres'] = None

        # set to None if tags (nullable) is None
        if self.tags is None:
            _dict['tags'] = None

        # set to None if episodes_changed (nullable) is None
        if self.episodes_changed is None:
            _dict['episodesChanged'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SeriesResource:
        """Create an instance of SeriesResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return SeriesResource.parse_obj(obj)

        _obj = SeriesResource.parse_obj({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "alternate_titles": [AlternateTitleResource.from_dict(_item) for _item in obj.get("alternateTitles")] if obj.get("alternateTitles") is not None else None,
            "sort_title": obj.get("sortTitle"),
            "status": obj.get("status"),
            "ended": obj.get("ended"),
            "profile_name": obj.get("profileName"),
            "overview": obj.get("overview"),
            "next_airing": obj.get("nextAiring"),
            "previous_airing": obj.get("previousAiring"),
            "network": obj.get("network"),
            "air_time": obj.get("airTime"),
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "original_language": Language.from_dict(obj.get("originalLanguage")) if obj.get("originalLanguage") is not None else None,
            "remote_poster": obj.get("remotePoster"),
            "seasons": [SeasonResource.from_dict(_item) for _item in obj.get("seasons")] if obj.get("seasons") is not None else None,
            "year": obj.get("year"),
            "path": obj.get("path"),
            "quality_profile_id": obj.get("qualityProfileId"),
            "season_folder": obj.get("seasonFolder"),
            "monitored": obj.get("monitored"),
            "use_scene_numbering": obj.get("useSceneNumbering"),
            "runtime": obj.get("runtime"),
            "tvdb_id": obj.get("tvdbId"),
            "tv_rage_id": obj.get("tvRageId"),
            "tv_maze_id": obj.get("tvMazeId"),
            "first_aired": obj.get("firstAired"),
            "series_type": obj.get("seriesType"),
            "clean_title": obj.get("cleanTitle"),
            "imdb_id": obj.get("imdbId"),
            "title_slug": obj.get("titleSlug"),
            "root_folder_path": obj.get("rootFolderPath"),
            "folder": obj.get("folder"),
            "certification": obj.get("certification"),
            "genres": obj.get("genres"),
            "tags": obj.get("tags"),
            "added": obj.get("added"),
            "add_options": AddSeriesOptions.from_dict(obj.get("addOptions")) if obj.get("addOptions") is not None else None,
            "ratings": Ratings.from_dict(obj.get("ratings")) if obj.get("ratings") is not None else None,
            "statistics": SeriesStatisticsResource.from_dict(obj.get("statistics")) if obj.get("statistics") is not None else None,
            "episodes_changed": obj.get("episodesChanged"),
            "language_profile_id": obj.get("languageProfileId")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel

class NamingConfigResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    rename_episodes: Optional[bool]
    replace_illegal_characters: Optional[bool]
    multi_episode_style: Optional[int]
    standard_episode_format: Optional[str]
    daily_episode_format: Optional[str]
    anime_episode_format: Optional[str]
    series_folder_format: Optional[str]
    season_folder_format: Optional[str]
    specials_folder_format: Optional[str]
    include_series_title: Optional[bool]
    include_episode_title: Optional[bool]
    include_quality: Optional[bool]
    replace_spaces: Optional[bool]
    separator: Optional[str]
    number_style: Optional[str]
    __properties = ["id", "renameEpisodes", "replaceIllegalCharacters", "multiEpisodeStyle", "standardEpisodeFormat", "dailyEpisodeFormat", "animeEpisodeFormat", "seriesFolderFormat", "seasonFolderFormat", "specialsFolderFormat", "includeSeriesTitle", "includeEpisodeTitle", "includeQuality", "replaceSpaces", "separator", "numberStyle"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> NamingConfigResource:
        """Create an instance of NamingConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if standard_episode_format (nullable) is None
        if self.standard_episode_format is None:
            _dict['standardEpisodeFormat'] = None

        # set to None if daily_episode_format (nullable) is None
        if self.daily_episode_format is None:
            _dict['dailyEpisodeFormat'] = None

        # set to None if anime_episode_format (nullable) is None
        if self.anime_episode_format is None:
            _dict['animeEpisodeFormat'] = None

        # set to None if series_folder_format (nullable) is None
        if self.series_folder_format is None:
            _dict['seriesFolderFormat'] = None

        # set to None if season_folder_format (nullable) is None
        if self.season_folder_format is None:
            _dict['seasonFolderFormat'] = None

        # set to None if specials_folder_format (nullable) is None
        if self.specials_folder_format is None:
            _dict['specialsFolderFormat'] = None

        # set to None if separator (nullable) is None
        if self.separator is None:
            _dict['separator'] = None

        # set to None if number_style (nullable) is None
        if self.number_style is None:
            _dict['numberStyle'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> NamingConfigResource:
        """Create an instance of NamingConfigResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return NamingConfigResource.parse_obj(obj)

        _obj = NamingConfigResource.parse_obj({
            "id": obj.get("id"),
            "rename_episodes": obj.get("renameEpisodes"),
            "replace_illegal_characters": obj.get("replaceIllegalCharacters"),
            "multi_episode_style": obj.get("multiEpisodeStyle"),
            "standard_episode_format": obj.get("standardEpisodeFormat"),
            "daily_episode_format": obj.get("dailyEpisodeFormat"),
            "anime_episode_format": obj.get("animeEpisodeFormat"),
            "series_folder_format": obj.get("seriesFolderFormat"),
            "season_folder_format": obj.get("seasonFolderFormat"),
            "specials_folder_format": obj.get("specialsFolderFormat"),
            "include_series_title": obj.get("includeSeriesTitle"),
            "include_episode_title": obj.get("includeEpisodeTitle"),
            "include_quality": obj.get("includeQuality"),
            "replace_spaces": obj.get("replaceSpaces"),
            "separator": obj.get("separator"),
            "number_style": obj.get("numberStyle")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.unmapped_folder import UnmappedFolder

class RootFolderResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    path: Optional[str]
    accessible: Optional[bool]
    free_space: Optional[int]
    unmapped_folders: Optional[List]
    __properties = ["id", "path", "accessible", "freeSpace", "unmappedFolders"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RootFolderResource:
        """Create an instance of RootFolderResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in unmapped_folders (list)
        _items = []
        if self.unmapped_folders:
            for _item in self.unmapped_folders:
                if _item:
                    _items.append(_item.to_dict())
            _dict['unmappedFolders'] = _items
        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        # set to None if free_space (nullable) is None
        if self.free_space is None:
            _dict['freeSpace'] = None

        # set to None if unmapped_folders (nullable) is None
        if self.unmapped_folders is None:
            _dict['unmappedFolders'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RootFolderResource:
        """Create an instance of RootFolderResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return RootFolderResource.parse_obj(obj)

        _obj = RootFolderResource.parse_obj({
            "id": obj.get("id"),
            "path": obj.get("path"),
            "accessible": obj.get("accessible"),
            "free_space": obj.get("freeSpace"),
            "unmapped_folders": [UnmappedFolder.from_dict(_item) for _item in obj.get("unmappedFolders")] if obj.get("unmappedFolders") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.alternate_title_resource import AlternateTitleResource
from sonarr.models.custom_format_resource import CustomFormatResource
from sonarr.models.download_protocol import DownloadProtocol
from sonarr.models.language import Language
from sonarr.models.quality_model import QualityModel

class ReleaseResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    guid: Optional[str]
    quality: Optional[QualityModel]
    quality_weight: Optional[int]
    age: Optional[int]
    age_hours: Optional[float]
    age_minutes: Optional[float]
    size: Optional[int]
    indexer_id: Optional[int]
    indexer: Optional[str]
    release_group: Optional[str]
    sub_group: Optional[str]
    release_hash: Optional[str]
    title: Optional[str]
    full_season: Optional[bool]
    scene_source: Optional[bool]
    season_number: Optional[int]
    languages: Optional[List]
    language_weight: Optional[int]
    air_date: Optional[str]
    series_title: Optional[str]
    episode_numbers: Optional[List]
    absolute_episode_numbers: Optional[List]
    mapped_season_number: Optional[int]
    mapped_episode_numbers: Optional[List]
    mapped_absolute_episode_numbers: Optional[List]
    approved: Optional[bool]
    temporarily_rejected: Optional[bool]
    rejected: Optional[bool]
    tvdb_id: Optional[int]
    tv_rage_id: Optional[int]
    rejections: Optional[List]
    publish_date: Optional[datetime]
    comment_url: Optional[str]
    download_url: Optional[str]
    info_url: Optional[str]
    episode_requested: Optional[bool]
    download_allowed: Optional[bool]
    release_weight: Optional[int]
    custom_formats: Optional[List]
    custom_format_score: Optional[int]
    scene_mapping: Optional[AlternateTitleResource]
    magnet_url: Optional[str]
    info_hash: Optional[str]
    seeders: Optional[int]
    leechers: Optional[int]
    protocol: Optional[DownloadProtocol]
    is_daily: Optional[bool]
    is_absolute_numbering: Optional[bool]
    is_possible_special_episode: Optional[bool]
    special: Optional[bool]
    series_id: Optional[int]
    episode_id: Optional[int]
    __properties = ["id", "guid", "quality", "qualityWeight", "age", "ageHours", "ageMinutes", "size", "indexerId", "indexer", "releaseGroup", "subGroup", "releaseHash", "title", "fullSeason", "sceneSource", "seasonNumber", "languages", "languageWeight", "airDate", "seriesTitle", "episodeNumbers", "absoluteEpisodeNumbers", "mappedSeasonNumber", "mappedEpisodeNumbers", "mappedAbsoluteEpisodeNumbers", "approved", "temporarilyRejected", "rejected", "tvdbId", "tvRageId", "rejections", "publishDate", "commentUrl", "downloadUrl", "infoUrl", "episodeRequested", "downloadAllowed", "releaseWeight", "customFormats", "customFormatScore", "sceneMapping", "magnetUrl", "infoHash", "seeders", "leechers", "protocol", "isDaily", "isAbsoluteNumbering", "isPossibleSpecialEpisode", "special", "seriesId", "episodeId"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ReleaseResource:
        """Create an instance of ReleaseResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item in self.languages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['languages'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in custom_formats (list)
        _items = []
        if self.custom_formats:
            for _item in self.custom_formats:
                if _item:
                    _items.append(_item.to_dict())
            _dict['customFormats'] = _items
        # override the default output from pydantic by calling `to_dict()` of scene_mapping
        if self.scene_mapping:
            _dict['sceneMapping'] = self.scene_mapping.to_dict()
        # set to None if guid (nullable) is None
        if self.guid is None:
            _dict['guid'] = None

        # set to None if indexer (nullable) is None
        if self.indexer is None:
            _dict['indexer'] = None

        # set to None if release_group (nullable) is None
        if self.release_group is None:
            _dict['releaseGroup'] = None

        # set to None if sub_group (nullable) is None
        if self.sub_group is None:
            _dict['subGroup'] = None

        # set to None if release_hash (nullable) is None
        if self.release_hash is None:
            _dict['releaseHash'] = None

        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if languages (nullable) is None
        if self.languages is None:
            _dict['languages'] = None

        # set to None if air_date (nullable) is None
        if self.air_date is None:
            _dict['airDate'] = None

        # set to None if series_title (nullable) is None
        if self.series_title is None:
            _dict['seriesTitle'] = None

        # set to None if episode_numbers (nullable) is None
        if self.episode_numbers is None:
            _dict['episodeNumbers'] = None

        # set to None if absolute_episode_numbers (nullable) is None
        if self.absolute_episode_numbers is None:
            _dict['absoluteEpisodeNumbers'] = None

        # set to None if mapped_season_number (nullable) is None
        if self.mapped_season_number is None:
            _dict['mappedSeasonNumber'] = None

        # set to None if mapped_episode_numbers (nullable) is None
        if self.mapped_episode_numbers is None:
            _dict['mappedEpisodeNumbers'] = None

        # set to None if mapped_absolute_episode_numbers (nullable) is None
        if self.mapped_absolute_episode_numbers is None:
            _dict['mappedAbsoluteEpisodeNumbers'] = None

        # set to None if rejections (nullable) is None
        if self.rejections is None:
            _dict['rejections'] = None

        # set to None if comment_url (nullable) is None
        if self.comment_url is None:
            _dict['commentUrl'] = None

        # set to None if download_url (nullable) is None
        if self.download_url is None:
            _dict['downloadUrl'] = None

        # set to None if info_url (nullable) is None
        if self.info_url is None:
            _dict['infoUrl'] = None

        # set to None if custom_formats (nullable) is None
        if self.custom_formats is None:
            _dict['customFormats'] = None

        # set to None if magnet_url (nullable) is None
        if self.magnet_url is None:
            _dict['magnetUrl'] = None

        # set to None if info_hash (nullable) is None
        if self.info_hash is None:
            _dict['infoHash'] = None

        # set to None if seeders (nullable) is None
        if self.seeders is None:
            _dict['seeders'] = None

        # set to None if leechers (nullable) is None
        if self.leechers is None:
            _dict['leechers'] = None

        # set to None if series_id (nullable) is None
        if self.series_id is None:
            _dict['seriesId'] = None

        # set to None if episode_id (nullable) is None
        if self.episode_id is None:
            _dict['episodeId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ReleaseResource:
        """Create an instance of ReleaseResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ReleaseResource.parse_obj(obj)

        _obj = ReleaseResource.parse_obj({
            "id": obj.get("id"),
            "guid": obj.get("guid"),
            "quality": QualityModel.from_dict(obj.get("quality")) if obj.get("quality") is not None else None,
            "quality_weight": obj.get("qualityWeight"),
            "age": obj.get("age"),
            "age_hours": obj.get("ageHours"),
            "age_minutes": obj.get("ageMinutes"),
            "size": obj.get("size"),
            "indexer_id": obj.get("indexerId"),
            "indexer": obj.get("indexer"),
            "release_group": obj.get("releaseGroup"),
            "sub_group": obj.get("subGroup"),
            "release_hash": obj.get("releaseHash"),
            "title": obj.get("title"),
            "full_season": obj.get("fullSeason"),
            "scene_source": obj.get("sceneSource"),
            "season_number": obj.get("seasonNumber"),
            "languages": [Language.from_dict(_item) for _item in obj.get("languages")] if obj.get("languages") is not None else None,
            "language_weight": obj.get("languageWeight"),
            "air_date": obj.get("airDate"),
            "series_title": obj.get("seriesTitle"),
            "episode_numbers": obj.get("episodeNumbers"),
            "absolute_episode_numbers": obj.get("absoluteEpisodeNumbers"),
            "mapped_season_number": obj.get("mappedSeasonNumber"),
            "mapped_episode_numbers": obj.get("mappedEpisodeNumbers"),
            "mapped_absolute_episode_numbers": obj.get("mappedAbsoluteEpisodeNumbers"),
            "approved": obj.get("approved"),
            "temporarily_rejected": obj.get("temporarilyRejected"),
            "rejected": obj.get("rejected"),
            "tvdb_id": obj.get("tvdbId"),
            "tv_rage_id": obj.get("tvRageId"),
            "rejections": obj.get("rejections"),
            "publish_date": obj.get("publishDate"),
            "comment_url": obj.get("commentUrl"),
            "download_url": obj.get("downloadUrl"),
            "info_url": obj.get("infoUrl"),
            "episode_requested": obj.get("episodeRequested"),
            "download_allowed": obj.get("downloadAllowed"),
            "release_weight": obj.get("releaseWeight"),
            "custom_formats": [CustomFormatResource.from_dict(_item) for _item in obj.get("customFormats")] if obj.get("customFormats") is not None else None,
            "custom_format_score": obj.get("customFormatScore"),
            "scene_mapping": AlternateTitleResource.from_dict(obj.get("sceneMapping")) if obj.get("sceneMapping") is not None else None,
            "magnet_url": obj.get("magnetUrl"),
            "info_hash": obj.get("infoHash"),
            "seeders": obj.get("seeders"),
            "leechers": obj.get("leechers"),
            "protocol": obj.get("protocol"),
            "is_daily": obj.get("isDaily"),
            "is_absolute_numbering": obj.get("isAbsoluteNumbering"),
            "is_possible_special_episode": obj.get("isPossibleSpecialEpisode"),
            "special": obj.get("special"),
            "series_id": obj.get("seriesId"),
            "episode_id": obj.get("episodeId")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, validator
from sonarr.models.custom_format_resource import CustomFormatResource
from sonarr.models.download_protocol import DownloadProtocol
from sonarr.models.episode_resource import EpisodeResource
from sonarr.models.language import Language
from sonarr.models.quality_model import QualityModel
from sonarr.models.series_resource import SeriesResource
from sonarr.models.tracked_download_state import TrackedDownloadState
from sonarr.models.tracked_download_status import TrackedDownloadStatus
from sonarr.models.tracked_download_status_message import TrackedDownloadStatusMessage

class QueueResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    series_id: Optional[int]
    episode_id: Optional[int]
    series: Optional[SeriesResource]
    episode: Optional[EpisodeResource]
    languages: Optional[List]
    quality: Optional[QualityModel]
    custom_formats: Optional[List]
    size: Optional[float]
    title: Optional[str]
    sizeleft: Optional[float]
    timeleft: Optional[str]
    estimated_completion_time: Optional[datetime]
    status: Optional[str]
    tracked_download_status: Optional[TrackedDownloadStatus]
    tracked_download_state: Optional[TrackedDownloadState]
    status_messages: Optional[List]
    error_message: Optional[str]
    download_id: Optional[str]
    protocol: Optional[DownloadProtocol]
    download_client: Optional[str]
    indexer: Optional[str]
    output_path: Optional[str]
    __properties = ["id", "seriesId", "episodeId", "series", "episode", "languages", "quality", "customFormats", "size", "title", "sizeleft", "timeleft", "estimatedCompletionTime", "status", "trackedDownloadStatus", "trackedDownloadState", "statusMessages", "errorMessage", "downloadId", "protocol", "downloadClient", "indexer", "outputPath"]

    @validator('timeleft')
    def timeleft_validate_regular_expression(cls, v):
        if not re.match(r"\d{2}:\d{2}:\d{2}", v):
            raise ValueError(r"must validate the regular expression /\d{2}:\d{2}:\d{2}/")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> QueueResource:
        """Create an instance of QueueResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of series
        if self.series:
            _dict['series'] = self.series.to_dict()
        # override the default output from pydantic by calling `to_dict()` of episode
        if self.episode:
            _dict['episode'] = self.episode.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item in self.languages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['languages'] = _items
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in custom_formats (list)
        _items = []
        if self.custom_formats:
            for _item in self.custom_formats:
                if _item:
                    _items.append(_item.to_dict())
            _dict['customFormats'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in status_messages (list)
        _items = []
        if self.status_messages:
            for _item in self.status_messages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['statusMessages'] = _items
        # set to None if series_id (nullable) is None
        if self.series_id is None:
            _dict['seriesId'] = None

        # set to None if episode_id (nullable) is None
        if self.episode_id is None:
            _dict['episodeId'] = None

        # set to None if languages (nullable) is None
        if self.languages is None:
            _dict['languages'] = None

        # set to None if custom_formats (nullable) is None
        if self.custom_formats is None:
            _dict['customFormats'] = None

        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if estimated_completion_time (nullable) is None
        if self.estimated_completion_time is None:
            _dict['estimatedCompletionTime'] = None

        # set to None if status (nullable) is None
        if self.status is None:
            _dict['status'] = None

        # set to None if status_messages (nullable) is None
        if self.status_messages is None:
            _dict['statusMessages'] = None

        # set to None if error_message (nullable) is None
        if self.error_message is None:
            _dict['errorMessage'] = None

        # set to None if download_id (nullable) is None
        if self.download_id is None:
            _dict['downloadId'] = None

        # set to None if download_client (nullable) is None
        if self.download_client is None:
            _dict['downloadClient'] = None

        # set to None if indexer (nullable) is None
        if self.indexer is None:
            _dict['indexer'] = None

        # set to None if output_path (nullable) is None
        if self.output_path is None:
            _dict['outputPath'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> QueueResource:
        """Create an instance of QueueResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return QueueResource.parse_obj(obj)

        _obj = QueueResource.parse_obj({
            "id": obj.get("id"),
            "series_id": obj.get("seriesId"),
            "episode_id": obj.get("episodeId"),
            "series": SeriesResource.from_dict(obj.get("series")) if obj.get("series") is not None else None,
            "episode": EpisodeResource.from_dict(obj.get("episode")) if obj.get("episode") is not None else None,
            "languages": [Language.from_dict(_item) for _item in obj.get("languages")] if obj.get("languages") is not None else None,
            "quality": QualityModel.from_dict(obj.get("quality")) if obj.get("quality") is not None else None,
            "custom_formats": [CustomFormatResource.from_dict(_item) for _item in obj.get("customFormats")] if obj.get("customFormats") is not None else None,
            "size": obj.get("size"),
            "title": obj.get("title"),
            "sizeleft": obj.get("sizeleft"),
            "timeleft": obj.get("timeleft"),
            "estimated_completion_time": obj.get("estimatedCompletionTime"),
            "status": obj.get("status"),
            "tracked_download_status": obj.get("trackedDownloadStatus"),
            "tracked_download_state": obj.get("trackedDownloadState"),
            "status_messages": [TrackedDownloadStatusMessage.from_dict(_item) for _item in obj.get("statusMessages")] if obj.get("statusMessages") is not None else None,
            "error_message": obj.get("errorMessage"),
            "download_id": obj.get("downloadId"),
            "protocol": obj.get("protocol"),
            "download_client": obj.get("downloadClient"),
            "indexer": obj.get("indexer"),
            "output_path": obj.get("outputPath")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel
from sonarr.models.authentication_type import AuthenticationType
from sonarr.models.runtime_mode import RuntimeMode
from sonarr.models.update_mechanism import UpdateMechanism

class SystemResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    app_name: Optional[str]
    instance_name: Optional[str]
    version: Optional[str]
    build_time: Optional[datetime]
    is_debug: Optional[bool]
    is_production: Optional[bool]
    is_admin: Optional[bool]
    is_user_interactive: Optional[bool]
    startup_path: Optional[str]
    app_data: Optional[str]
    os_name: Optional[str]
    os_version: Optional[str]
    is_net_core: Optional[bool]
    is_linux: Optional[bool]
    is_osx: Optional[bool]
    is_windows: Optional[bool]
    is_docker: Optional[bool]
    mode: Optional[RuntimeMode]
    branch: Optional[str]
    authentication: Optional[AuthenticationType]
    sqlite_version: Optional[str]
    migration_version: Optional[int]
    url_base: Optional[str]
    runtime_version: Optional[str]
    runtime_name: Optional[str]
    start_time: Optional[datetime]
    package_version: Optional[str]
    package_author: Optional[str]
    package_update_mechanism: Optional[UpdateMechanism]
    package_update_mechanism_message: Optional[str]
    __properties = ["appName", "instanceName", "version", "buildTime", "isDebug", "isProduction", "isAdmin", "isUserInteractive", "startupPath", "appData", "osName", "osVersion", "isNetCore", "isLinux", "isOsx", "isWindows", "isDocker", "mode", "branch", "authentication", "sqliteVersion", "migrationVersion", "urlBase", "runtimeVersion", "runtimeName", "startTime", "packageVersion", "packageAuthor", "packageUpdateMechanism", "packageUpdateMechanismMessage"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SystemResource:
        """Create an instance of SystemResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if app_name (nullable) is None
        if self.app_name is None:
            _dict['appName'] = None

        # set to None if instance_name (nullable) is None
        if self.instance_name is None:
            _dict['instanceName'] = None

        # set to None if version (nullable) is None
        if self.version is None:
            _dict['version'] = None

        # set to None if startup_path (nullable) is None
        if self.startup_path is None:
            _dict['startupPath'] = None

        # set to None if app_data (nullable) is None
        if self.app_data is None:
            _dict['appData'] = None

        # set to None if os_name (nullable) is None
        if self.os_name is None:
            _dict['osName'] = None

        # set to None if os_version (nullable) is None
        if self.os_version is None:
            _dict['osVersion'] = None

        # set to None if branch (nullable) is None
        if self.branch is None:
            _dict['branch'] = None

        # set to None if url_base (nullable) is None
        if self.url_base is None:
            _dict['urlBase'] = None

        # set to None if runtime_name (nullable) is None
        if self.runtime_name is None:
            _dict['runtimeName'] = None

        # set to None if package_version (nullable) is None
        if self.package_version is None:
            _dict['packageVersion'] = None

        # set to None if package_author (nullable) is None
        if self.package_author is None:
            _dict['packageAuthor'] = None

        # set to None if package_update_mechanism_message (nullable) is None
        if self.package_update_mechanism_message is None:
            _dict['packageUpdateMechanismMessage'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SystemResource:
        """Create an instance of SystemResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return SystemResource.parse_obj(obj)

        _obj = SystemResource.parse_obj({
            "app_name": obj.get("appName"),
            "instance_name": obj.get("instanceName"),
            "version": obj.get("version"),
            "build_time": obj.get("buildTime"),
            "is_debug": obj.get("isDebug"),
            "is_production": obj.get("isProduction"),
            "is_admin": obj.get("isAdmin"),
            "is_user_interactive": obj.get("isUserInteractive"),
            "startup_path": obj.get("startupPath"),
            "app_data": obj.get("appData"),
            "os_name": obj.get("osName"),
            "os_version": obj.get("osVersion"),
            "is_net_core": obj.get("isNetCore"),
            "is_linux": obj.get("isLinux"),
            "is_osx": obj.get("isOsx"),
            "is_windows": obj.get("isWindows"),
            "is_docker": obj.get("isDocker"),
            "mode": obj.get("mode"),
            "branch": obj.get("branch"),
            "authentication": obj.get("authentication"),
            "sqlite_version": obj.get("sqliteVersion"),
            "migration_version": obj.get("migrationVersion"),
            "url_base": obj.get("urlBase"),
            "runtime_version": obj.get("runtimeVersion"),
            "runtime_name": obj.get("runtimeName"),
            "start_time": obj.get("startTime"),
            "package_version": obj.get("packageVersion"),
            "package_author": obj.get("packageAuthor"),
            "package_update_mechanism": obj.get("packageUpdateMechanism"),
            "package_update_mechanism_message": obj.get("packageUpdateMechanismMessage")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.language import Language
from sonarr.models.quality_model import QualityModel
from sonarr.models.series_title_info import SeriesTitleInfo

class ParsedEpisodeInfo(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    release_title: Optional[str]
    series_title: Optional[str]
    series_title_info: Optional[SeriesTitleInfo]
    quality: Optional[QualityModel]
    season_number: Optional[int]
    episode_numbers: Optional[List]
    absolute_episode_numbers: Optional[List]
    special_absolute_episode_numbers: Optional[List]
    air_date: Optional[str]
    languages: Optional[List]
    full_season: Optional[bool]
    is_partial_season: Optional[bool]
    is_multi_season: Optional[bool]
    is_season_extra: Optional[bool]
    special: Optional[bool]
    release_group: Optional[str]
    release_hash: Optional[str]
    season_part: Optional[int]
    release_tokens: Optional[str]
    daily_part: Optional[int]
    is_daily: Optional[bool]
    is_absolute_numbering: Optional[bool]
    is_possible_special_episode: Optional[bool]
    is_possible_scene_season_special: Optional[bool]
    __properties = ["releaseTitle", "seriesTitle", "seriesTitleInfo", "quality", "seasonNumber", "episodeNumbers", "absoluteEpisodeNumbers", "specialAbsoluteEpisodeNumbers", "airDate", "languages", "fullSeason", "isPartialSeason", "isMultiSeason", "isSeasonExtra", "special", "releaseGroup", "releaseHash", "seasonPart", "releaseTokens", "dailyPart", "isDaily", "isAbsoluteNumbering", "isPossibleSpecialEpisode", "isPossibleSceneSeasonSpecial"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParsedEpisodeInfo:
        """Create an instance of ParsedEpisodeInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "is_daily",
                            "is_absolute_numbering",
                            "is_possible_special_episode",
                            "is_possible_scene_season_special",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of series_title_info
        if self.series_title_info:
            _dict['seriesTitleInfo'] = self.series_title_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item in self.languages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['languages'] = _items
        # set to None if release_title (nullable) is None
        if self.release_title is None:
            _dict['releaseTitle'] = None

        # set to None if series_title (nullable) is None
        if self.series_title is None:
            _dict['seriesTitle'] = None

        # set to None if episode_numbers (nullable) is None
        if self.episode_numbers is None:
            _dict['episodeNumbers'] = None

        # set to None if absolute_episode_numbers (nullable) is None
        if self.absolute_episode_numbers is None:
            _dict['absoluteEpisodeNumbers'] = None

        # set to None if special_absolute_episode_numbers (nullable) is None
        if self.special_absolute_episode_numbers is None:
            _dict['specialAbsoluteEpisodeNumbers'] = None

        # set to None if air_date (nullable) is None
        if self.air_date is None:
            _dict['airDate'] = None

        # set to None if languages (nullable) is None
        if self.languages is None:
            _dict['languages'] = None

        # set to None if release_group (nullable) is None
        if self.release_group is None:
            _dict['releaseGroup'] = None

        # set to None if release_hash (nullable) is None
        if self.release_hash is None:
            _dict['releaseHash'] = None

        # set to None if release_tokens (nullable) is None
        if self.release_tokens is None:
            _dict['releaseTokens'] = None

        # set to None if daily_part (nullable) is None
        if self.daily_part is None:
            _dict['dailyPart'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParsedEpisodeInfo:
        """Create an instance of ParsedEpisodeInfo from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ParsedEpisodeInfo.parse_obj(obj)

        _obj = ParsedEpisodeInfo.parse_obj({
            "release_title": obj.get("releaseTitle"),
            "series_title": obj.get("seriesTitle"),
            "series_title_info": SeriesTitleInfo.from_dict(obj.get("seriesTitleInfo")) if obj.get("seriesTitleInfo") is not None else None,
            "quality": QualityModel.from_dict(obj.get("quality")) if obj.get("quality") is not None else None,
            "season_number": obj.get("seasonNumber"),
            "episode_numbers": obj.get("episodeNumbers"),
            "absolute_episode_numbers": obj.get("absoluteEpisodeNumbers"),
            "special_absolute_episode_numbers": obj.get("specialAbsoluteEpisodeNumbers"),
            "air_date": obj.get("airDate"),
            "languages": [Language.from_dict(_item) for _item in obj.get("languages")] if obj.get("languages") is not None else None,
            "full_season": obj.get("fullSeason"),
            "is_partial_season": obj.get("isPartialSeason"),
            "is_multi_season": obj.get("isMultiSeason"),
            "is_season_extra": obj.get("isSeasonExtra"),
            "special": obj.get("special"),
            "release_group": obj.get("releaseGroup"),
            "release_hash": obj.get("releaseHash"),
            "season_part": obj.get("seasonPart"),
            "release_tokens": obj.get("releaseTokens"),
            "daily_part": obj.get("dailyPart"),
            "is_daily": obj.get("isDaily"),
            "is_absolute_numbering": obj.get("isAbsoluteNumbering"),
            "is_possible_special_episode": obj.get("isPossibleSpecialEpisode"),
            "is_possible_scene_season_special": obj.get("isPossibleSceneSeasonSpecial")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.custom_format_resource import CustomFormatResource
from sonarr.models.language import Language
from sonarr.models.media_info_resource import MediaInfoResource
from sonarr.models.quality_model import QualityModel

class EpisodeFileResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    series_id: Optional[int]
    season_number: Optional[int]
    relative_path: Optional[str]
    path: Optional[str]
    size: Optional[int]
    date_added: Optional[datetime]
    scene_name: Optional[str]
    release_group: Optional[str]
    languages: Optional[List]
    quality: Optional[QualityModel]
    custom_formats: Optional[List]
    media_info: Optional[MediaInfoResource]
    quality_cutoff_not_met: Optional[bool]
    __properties = ["id", "seriesId", "seasonNumber", "relativePath", "path", "size", "dateAdded", "sceneName", "releaseGroup", "languages", "quality", "customFormats", "mediaInfo", "qualityCutoffNotMet"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EpisodeFileResource:
        """Create an instance of EpisodeFileResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item in self.languages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['languages'] = _items
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in custom_formats (list)
        _items = []
        if self.custom_formats:
            for _item in self.custom_formats:
                if _item:
                    _items.append(_item.to_dict())
            _dict['customFormats'] = _items
        # override the default output from pydantic by calling `to_dict()` of media_info
        if self.media_info:
            _dict['mediaInfo'] = self.media_info.to_dict()
        # set to None if relative_path (nullable) is None
        if self.relative_path is None:
            _dict['relativePath'] = None

        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        # set to None if scene_name (nullable) is None
        if self.scene_name is None:
            _dict['sceneName'] = None

        # set to None if release_group (nullable) is None
        if self.release_group is None:
            _dict['releaseGroup'] = None

        # set to None if languages (nullable) is None
        if self.languages is None:
            _dict['languages'] = None

        # set to None if custom_formats (nullable) is None
        if self.custom_formats is None:
            _dict['customFormats'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EpisodeFileResource:
        """Create an instance of EpisodeFileResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return EpisodeFileResource.parse_obj(obj)

        _obj = EpisodeFileResource.parse_obj({
            "id": obj.get("id"),
            "series_id": obj.get("seriesId"),
            "season_number": obj.get("seasonNumber"),
            "relative_path": obj.get("relativePath"),
            "path": obj.get("path"),
            "size": obj.get("size"),
            "date_added": obj.get("dateAdded"),
            "scene_name": obj.get("sceneName"),
            "release_group": obj.get("releaseGroup"),
            "languages": [Language.from_dict(_item) for _item in obj.get("languages")] if obj.get("languages") is not None else None,
            "quality": QualityModel.from_dict(obj.get("quality")) if obj.get("quality") is not None else None,
            "custom_formats": [CustomFormatResource.from_dict(_item) for _item in obj.get("customFormats")] if obj.get("customFormats") is not None else None,
            "media_info": MediaInfoResource.from_dict(obj.get("mediaInfo")) if obj.get("mediaInfo") is not None else None,
            "quality_cutoff_not_met": obj.get("qualityCutoffNotMet")
        })
        return _obj




# coding: utf-8

# flake8: noqa

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


# import apis into api package
from sonarr.api.api_info_api import ApiInfoApi
from sonarr.api.authentication_api import AuthenticationApi
from sonarr.api.auto_tagging_api import AutoTaggingApi
from sonarr.api.backup_api import BackupApi
from sonarr.api.blocklist_api import BlocklistApi
from sonarr.api.calendar_api import CalendarApi
from sonarr.api.calendar_feed_api import CalendarFeedApi
from sonarr.api.command_api import CommandApi
from sonarr.api.custom_filter_api import CustomFilterApi
from sonarr.api.custom_format_api import CustomFormatApi
from sonarr.api.cutoff_api import CutoffApi
from sonarr.api.delay_profile_api import DelayProfileApi
from sonarr.api.disk_space_api import DiskSpaceApi
from sonarr.api.download_client_api import DownloadClientApi
from sonarr.api.download_client_config_api import DownloadClientConfigApi
from sonarr.api.episode_api import EpisodeApi
from sonarr.api.episode_file_api import EpisodeFileApi
from sonarr.api.file_system_api import FileSystemApi
from sonarr.api.health_api import HealthApi
from sonarr.api.history_api import HistoryApi
from sonarr.api.host_config_api import HostConfigApi
from sonarr.api.import_list_api import ImportListApi
from sonarr.api.import_list_exclusion_api import ImportListExclusionApi
from sonarr.api.indexer_api import IndexerApi
from sonarr.api.indexer_config_api import IndexerConfigApi
from sonarr.api.initialize_js_api import InitializeJsApi
from sonarr.api.language_api import LanguageApi
from sonarr.api.language_profile_api import LanguageProfileApi
from sonarr.api.language_profile_schema_api import LanguageProfileSchemaApi
from sonarr.api.localization_api import LocalizationApi
from sonarr.api.log_api import LogApi
from sonarr.api.log_file_api import LogFileApi
from sonarr.api.manual_import_api import ManualImportApi
from sonarr.api.media_cover_api import MediaCoverApi
from sonarr.api.media_management_config_api import MediaManagementConfigApi
from sonarr.api.metadata_api import MetadataApi
from sonarr.api.missing_api import MissingApi
from sonarr.api.naming_config_api import NamingConfigApi
from sonarr.api.notification_api import NotificationApi
from sonarr.api.parse_api import ParseApi
from sonarr.api.ping_api import PingApi
from sonarr.api.quality_definition_api import QualityDefinitionApi
from sonarr.api.quality_profile_api import QualityProfileApi
from sonarr.api.quality_profile_schema_api import QualityProfileSchemaApi
from sonarr.api.queue_api import QueueApi
from sonarr.api.queue_action_api import QueueActionApi
from sonarr.api.queue_details_api import QueueDetailsApi
from sonarr.api.queue_status_api import QueueStatusApi
from sonarr.api.release_api import ReleaseApi
from sonarr.api.release_profile_api import ReleaseProfileApi
from sonarr.api.release_push_api import ReleasePushApi
from sonarr.api.remote_path_mapping_api import RemotePathMappingApi
from sonarr.api.rename_episode_api import RenameEpisodeApi
from sonarr.api.root_folder_api import RootFolderApi
from sonarr.api.season_pass_api import SeasonPassApi
from sonarr.api.series_api import SeriesApi
from sonarr.api.series_editor_api import SeriesEditorApi
from sonarr.api.series_import_api import SeriesImportApi
from sonarr.api.series_lookup_api import SeriesLookupApi
from sonarr.api.static_resource_api import StaticResourceApi
from sonarr.api.system_api import SystemApi
from sonarr.api.tag_api import TagApi
from sonarr.api.tag_details_api import TagDetailsApi
from sonarr.api.task_api import TaskApi
from sonarr.api.ui_config_api import UiConfigApi
from sonarr.api.update_api import UpdateApi
from sonarr.api.update_log_file_api import UpdateLogFileApi



# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel

class MediaInfoResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    audio_bitrate: Optional[int]
    audio_channels: Optional[float]
    audio_codec: Optional[str]
    audio_languages: Optional[str]
    audio_stream_count: Optional[int]
    video_bit_depth: Optional[int]
    video_bitrate: Optional[int]
    video_codec: Optional[str]
    video_fps: Optional[float]
    video_dynamic_range: Optional[str]
    video_dynamic_range_type: Optional[str]
    resolution: Optional[str]
    run_time: Optional[str]
    scan_type: Optional[str]
    subtitles: Optional[str]
    __properties = ["id", "audioBitrate", "audioChannels", "audioCodec", "audioLanguages", "audioStreamCount", "videoBitDepth", "videoBitrate", "videoCodec", "videoFps", "videoDynamicRange", "videoDynamicRangeType", "resolution", "runTime", "scanType", "subtitles"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MediaInfoResource:
        """Create an instance of MediaInfoResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if audio_codec (nullable) is None
        if self.audio_codec is None:
            _dict['audioCodec'] = None

        # set to None if audio_languages (nullable) is None
        if self.audio_languages is None:
            _dict['audioLanguages'] = None

        # set to None if video_codec (nullable) is None
        if self.video_codec is None:
            _dict['videoCodec'] = None

        # set to None if video_dynamic_range (nullable) is None
        if self.video_dynamic_range is None:
            _dict['videoDynamicRange'] = None

        # set to None if video_dynamic_range_type (nullable) is None
        if self.video_dynamic_range_type is None:
            _dict['videoDynamicRangeType'] = None

        # set to None if resolution (nullable) is None
        if self.resolution is None:
            _dict['resolution'] = None

        # set to None if run_time (nullable) is None
        if self.run_time is None:
            _dict['runTime'] = None

        # set to None if scan_type (nullable) is None
        if self.scan_type is None:
            _dict['scanType'] = None

        # set to None if subtitles (nullable) is None
        if self.subtitles is None:
            _dict['subtitles'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MediaInfoResource:
        """Create an instance of MediaInfoResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MediaInfoResource.parse_obj(obj)

        _obj = MediaInfoResource.parse_obj({
            "id": obj.get("id"),
            "audio_bitrate": obj.get("audioBitrate"),
            "audio_channels": obj.get("audioChannels"),
            "audio_codec": obj.get("audioCodec"),
            "audio_languages": obj.get("audioLanguages"),
            "audio_stream_count": obj.get("audioStreamCount"),
            "video_bit_depth": obj.get("videoBitDepth"),
            "video_bitrate": obj.get("videoBitrate"),
            "video_codec": obj.get("videoCodec"),
            "video_fps": obj.get("videoFps"),
            "video_dynamic_range": obj.get("videoDynamicRange"),
            "video_dynamic_range_type": obj.get("videoDynamicRangeType"),
            "resolution": obj.get("resolution"),
            "run_time": obj.get("runTime"),
            "scan_type": obj.get("scanType"),
            "subtitles": obj.get("subtitles")
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup

setup()



# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.monitoring_options import MonitoringOptions
from sonarr.models.season_pass_series_resource import SeasonPassSeriesResource

class SeasonPassResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    series: Optional[List]
    monitoring_options: Optional[MonitoringOptions]
    __properties = ["series", "monitoringOptions"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SeasonPassResource:
        """Create an instance of SeasonPassResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in series (list)
        _items = []
        if self.series:
            for _item in self.series:
                if _item:
                    _items.append(_item.to_dict())
            _dict['series'] = _items
        # override the default output from pydantic by calling `to_dict()` of monitoring_options
        if self.monitoring_options:
            _dict['monitoringOptions'] = self.monitoring_options.to_dict()
        # set to None if series (nullable) is None
        if self.series is None:
            _dict['series'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SeasonPassResource:
        """Create an instance of SeasonPassResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return SeasonPassResource.parse_obj(obj)

        _obj = SeasonPassResource.parse_obj({
            "series": [SeasonPassSeriesResource.from_dict(_item) for _item in obj.get("series")] if obj.get("series") is not None else None,
            "monitoring_options": MonitoringOptions.from_dict(obj.get("monitoringOptions")) if obj.get("monitoringOptions") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Sonarr

    Sonarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from sonarr.models.log_resource import LogResource
from sonarr.models.paging_resource_filter import PagingResourceFilter
from sonarr.models.sort_direction import SortDirection

class LogResourcePagingResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    page: Optional[int]
    page_size: Optional[int]
    sort_key: Optional[str]
    sort_direction: Optional[SortDirection]
    filters: Optional[List]
    total_records: Optional[int]
    records: Optional[List]
    __properties = ["page", "pageSize", "sortKey", "sortDirection", "filters", "totalRecords", "records"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LogResourcePagingResource:
        """Create an instance of LogResourcePagingResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in filters (list)
        _items = []
        if self.filters:
            for _item in self.filters:
                if _item:
                    _items.append(_item.to_dict())
            _dict['filters'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in records (list)
        _items = []
        if self.records:
            for _item in self.records:
                if _item:
                    _items.append(_item.to_dict())
            _dict['records'] = _items
        # set to None if sort_key (nullable) is None
        if self.sort_key is None:
            _dict['sortKey'] = None

        # set to None if filters (nullable) is None
        if self.filters is None:
            _dict['filters'] = None

        # set to None if records (nullable) is None
        if self.records is None:
            _dict['records'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LogResourcePagingResource:
        """Create an instance of LogResourcePagingResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return LogResourcePagingResource.parse_obj(obj)

        _obj = LogResourcePagingResource.parse_obj({
            "page": obj.get("page"),
            "page_size": obj.get("pageSize"),
            "sort_key": obj.get("sortKey"),
            "sort_direction": obj.get("sortDirection"),
            "filters": [PagingResourceFilter.from_dict(_item) for _item in obj.get("filters")] if obj.get("filters") is not None else None,
            "total_records": obj.get("totalRecords"),
            "records": [LogResource.from_dict(_item) for _item in obj.get("records")] if obj.get("records") is not None else None
        })
        return _obj

